@@ -20,8 +20,12 @@ from ironicclient.common import http
 from ironicclient.common.http import DEFAULT_VER
 from ironicclient.common.i18n import _
 from ironicclient import exc
+from ironicclient.v1 import allocation
 from ironicclient.v1 import chassis
+from ironicclient.v1 import conductor
+from ironicclient.v1 import deploy_template
 from ironicclient.v1 import driver
+from ironicclient.v1 import events
 from ironicclient.v1 import node
 from ironicclient.v1 import port
 from ironicclient.v1 import portgroup
@@ -34,8 +38,6 @@ LOG = logging.getLogger(__name__)
 class Client(object):
     """Client for the Ironic v1 API.
 
-    :param string endpoint: A user-supplied endpoint URL for the ironic
-                            service. DEPRECATED, use endpoint_override instead.
     :param string endpoint_override: A user-supplied endpoint URL for the
                                      ironic service.
     :param function token: Provides token for authentication.
@@ -43,17 +45,12 @@ class Client(object):
                             http requests. (optional)
     """
 
-    def __init__(self, endpoint=None, endpoint_override=None, *args, **kwargs):
+    def __init__(self, endpoint_override=None, *args, **kwargs):
         """Initialize a new client for the Ironic v1 API."""
         allow_downgrade = kwargs.pop('allow_api_version_downgrade', False)
-        if endpoint_override is None and endpoint is not None:
-            LOG.warning('Passing "endpoint" parameter to Client constructor '
-                        'is deprecated, and it will be removed in Stein '
-                        'release. Please use "endpoint_override" instead.')
-            endpoint_override = endpoint
         if kwargs.get('os_ironic_api_version'):
             # TODO(TheJulia): We should sanity check os_ironic_api_version
-            # against our maximum suported version, so the client fails
+            # against our maximum supported version, so the client fails
             # immediately upon an unsupported version being provided.
             # This logic should also likely live in common/http.py
             if allow_downgrade:
@@ -97,6 +94,11 @@ class Client(object):
             self.http_client)
         self.driver = driver.DriverManager(self.http_client)
         self.portgroup = portgroup.PortgroupManager(self.http_client)
+        self.conductor = conductor.ConductorManager(self.http_client)
+        self.events = events.EventManager(self.http_client)
+        self.allocation = allocation.AllocationManager(self.http_client)
+        self.deploy_template = deploy_template.DeployTemplateManager(
+            self.http_client)
 
     @property
     def current_api_version(self):
